GENDIS
======

.. autoclass:: gendis.genetic.GeneticExtractor




   .. rubric:: Methods

   .. autosummary::
      :toctree:

      __init__
      fit
      transform
      fit_transform
      save
      load